@@ -14,13 +14,14 @@
 
    Copyright 2022, HSPyLib team
 """
-import concurrent.futures
 import re
+from concurrent import futures
+from textwrap import dedent
 from time import sleep
 from typing import List
 
 from hspylib.addons.widman.widget import Widget
-from hspylib.core.enums.exit_code import ExitCode
+from hspylib.core.enums.exit_status import ExitStatus
 from hspylib.core.tools.commons import human_readable_bytes, sysout
 from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
 from hspylib.modules.cli.keyboard import Keyboard
@@ -29,13 +30,13 @@ from hspylib.modules.cli.vt100.terminal import Terminal
 
 class WidgetFree(Widget):
     """HSPyLib Widget to Report current system memory usage"""
-    WIDGET_ICON = WidgetIcons.DATABASE
+    WIDGET_ICON = WidgetIcons.CHIP
     WIDGET_NAME = "Free"
     TOOLTIP = "Report system memory usage."
     USAGE = "Usage: Free"
     VERSION = (0, 2, 0)
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(
             self.WIDGET_ICON,
             self.WIDGET_NAME,
@@ -44,16 +45,16 @@ class WidgetFree(Widget):
             self.VERSION)
         self._is_alive = True
         self._report_interval = 1.5
-        self._exit_code = ExitCode.SUCCESS
+        self._exit_code = ExitStatus.SUCCESS
 
-    def execute(self, args: List[str] = None) -> ExitCode:
-        with concurrent.futures.ThreadPoolExecutor() as executor:
+    def execute(self, args: List[str] = None) -> ExitStatus:
+        with futures.ThreadPoolExecutor() as executor:
             done = False
             while not done and not Keyboard.kbhit():
                 future = executor.submit(self._report_usage)
                 done = not future.result()
-                sleep(self._report_interval)
-
+                if not done:
+                    sleep(self._report_interval)
         return self._exit_code
 
     # pylint: disable=too-many-locals
@@ -63,7 +64,7 @@ class WidgetFree(Widget):
         ps, ec1 = Terminal.shell_exec('ps -caxm -orss,comm')  # Get process info
         vm, ec2 = Terminal.shell_exec('vm_stat')  # Grabbing memory characteristics
 
-        if ec1 == ExitCode.SUCCESS and ec2 == ExitCode.SUCCESS and ps:
+        if ec1 == ExitStatus.SUCCESS and ec2 == ExitStatus.SUCCESS and ps:
             process_lines = ps.split('\n')  # Iterate processes
             sep = re.compile(' +')
             rss_total = 0  # kB
@@ -92,14 +93,17 @@ class WidgetFree(Widget):
             free, fu = human_readable_bytes(vm_stats["Pages free"])
             real, ru = human_readable_bytes(rss_total)  # Total memory
 
-            sysout('%HOM%%ED2%%MOD(0)%', end='')
-            sysout(f"\n%ORANGE%Reporting system memory usage:%NC% \n{'-' * 30}")
-            sysout(f"    %GREEN%Wired Memory: {wired:6s} {wu:2s}")
-            sysout(f"   %GREEN%Active Memory: {active:6s} {au:2s}")
-            sysout(f" %GREEN%Inactive Memory: {inactive:6s} {iu:2s}")
-            sysout(f"     %GREEN%Free Memory: {free:6s} {fu:2s}")
-            sysout(f"     %GREEN%Real Memory: {real:6s} {ru:2s}")
-            sysout('\n%YELLOW%Press [Enter] to exit ...', end='')
+            sysout(dedent(f"""
+            %HOM%%ED2%%MOD(0)%
+            %ORANGE%Reporting system memory usage:%NC%
+            {'-' * 30}
+            %GREEN%   Wired Memory: {wired:6s} {wu:2s}
+            %GREEN%  Active Memory: {active:6s} {au:2s}
+            %GREEN%Inactive Memory: {inactive:6s} {iu:2s}
+            %GREEN%    Free Memory: {free:6s} {fu:2s}
+            %GREEN%    Real Memory: {real:6s} {ru:2s}
+
+            %YELLOW%Press [Enter] to exit ..."""))
 
             return True
 
